==> dojo-1.10.6.tgz: package/cldr/nls/hr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"months-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4.",
		"5.",
		"6.",
		"7.",
		"8.",
		"9.",
		"10.",
		"11.",
		"12."
	],
	"field-second-relative+0": "sada",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "Dan u tjednu",
	"dateFormatItem-yQQQ": "QQQ y.",
	"dateFormatItem-yMEd": "E, d. M. y.",
	"field-wed-relative+0": "ova srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-wed-relative+1": "sljedeća srijeda",
	"eraNarrow": [
		"pr.n.e.",
		"AD"
	],
	"dateFormatItem-yMM": "MM. y.",
	"field-tue-relative+-1": "prošli utorak",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-long": "d. MMMM y.",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"months-format-wide": [
		"siječnja",
		"veljače",
		"ožujka",
		"travnja",
		"svibnja",
		"lipnja",
		"srpnja",
		"kolovoza",
		"rujna",
		"listopada",
		"studenoga",
		"prosinca"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, d. MMMM y.",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "d. M.",
	"dayPeriods-format-wide-noon": "podne",
	"dateFormatItem-yMd": "d. M. y.",
	"dateFormatItem-yM": "M. y.",
	"field-era": "Era",
	"months-standAlone-wide": [
		"siječanj",
		"veljača",
		"ožujak",
		"travanj",
		"svibanj",
		"lipanj",
		"srpanj",
		"kolovoz",
		"rujan",
		"listopad",
		"studeni",
		"prosinac"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "LLL y.",
	"dateFormatItem-yQQQQ": "QQQQ y.",
	"field-year": "Godina",
	"dateFormatItem-MMdd": "dd. MM.",
	"field-hour": "Sat",
	"months-format-abbr": [
		"sij",
		"velj",
		"ožu",
		"tra",
		"svi",
		"lip",
		"srp",
		"kol",
		"ruj",
		"lis",
		"stu",
		"pro"
	],
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dayPeriods-format-narrow-morning": "prijepodne",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"sij",
		"velj",
		"ožu",
		"tra",
		"svi",
		"lip",
		"srp",
		"kol",
		"ruj",
		"lis",
		"stu",
		"pro"
	],
	"quarters-format-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dayPeriods-format-narrow-evening": "navečer",
	"dateFormatItem-MMMMd": "d. MMMM",
	"dayPeriods-format-abbr-noon": "podne",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "ova nedjelja",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"field-sun-relative+1": "sljedeća nedjelja",
	"eraAbbr": [
		"pr. Kr.",
		"p. Kr."
	],
	"field-minute": "Minuta",
	"field-dayperiod": "Prijepodne/popodne",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, d. M.",
	"dateTimeFormat-full": "{1} 'u' {0}",
	"field-fri-relative+0": "ovaj petak",
	"dateFormatItem-yMMMM": "LLLL y.",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-zone": "Vremenska zona",
	"months-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4.",
		"5.",
		"6.",
		"7.",
		"8.",
		"9.",
		"10.",
		"11.",
		"12."
	],
	"dateFormatItem-y": "y.",
	"field-year-relative+-1": "prošle godine",
	"dayPeriods-format-narrow-night": "noću",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"eraNames": [
		"Prije Krista",
		"Poslije Krista"
	],
	"dateFormatItem-yMMMd": "d. MMM y.",
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"dayPeriods-format-narrow-earlyMorning": "ujutro",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Mjesec",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "d.M.yy.",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-format-narrow-afternoon": "popodne",
	"dayPeriods-format-narrow-noon": "n",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"dateFormatItem-yMMMEd": "E, d. MMM y.",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. MMM y.",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"field-year-relative+1": "sljedeće godine",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);

==> dojo-1.13.5.tgz: package/cldr/nls/hr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"months-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4.",
		"5.",
		"6.",
		"7.",
		"8.",
		"9.",
		"10.",
		"11.",
		"12."
	],
	"field-second-relative+0": "sada",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-weekday": "Dan u tjednu",
	"dateFormatItem-yQQQ": "QQQ y.",
	"dateFormatItem-yMEd": "E, dd.MM.y.",
	"field-wed-relative+0": "ova srijeda",
	"dateFormatItem-GyMMMEd": "E, d. MMM y. G",
	"dateFormatItem-MMMEd": "E, d. MMM",
	"field-wed-relative+1": "sljedeća srijeda",
	"eraNarrow": [
		"pr.n.e.",
		"AD"
	],
	"dateFormatItem-yMM": "MM. y.",
	"field-tue-relative+-1": "prošli utorak",
	"days-format-short": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormat-long": "d. MMMM y.",
	"field-fri-relative+-1": "prošli petak",
	"field-wed-relative+-1": "prošla srijeda",
	"months-format-wide": [
		"siječnja",
		"veljače",
		"ožujka",
		"travnja",
		"svibnja",
		"lipnja",
		"srpnja",
		"kolovoza",
		"rujna",
		"listopada",
		"studenoga",
		"prosinca"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE, d. MMMM y.",
	"field-thu-relative+-1": "prošli četvrtak",
	"dateFormatItem-Md": "dd.MM.",
	"dayPeriods-format-wide-noon": "podne",
	"dateFormatItem-yMd": "dd.MM.y.",
	"dateFormatItem-yM": "MM.y.",
	"field-era": "Era",
	"months-standAlone-wide": [
		"siječanj",
		"veljača",
		"ožujak",
		"travanj",
		"svibanj",
		"lipanj",
		"srpanj",
		"kolovoz",
		"rujan",
		"listopad",
		"studeni",
		"prosinac"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "LLL y.",
	"dateFormatItem-yQQQQ": "QQQQ y.",
	"field-year": "Godina",
	"dateFormatItem-MMdd": "dd. MM.",
	"field-hour": "Sat",
	"months-format-abbr": [
		"sij",
		"velj",
		"ožu",
		"tra",
		"svi",
		"lip",
		"srp",
		"kol",
		"ruj",
		"lis",
		"stu",
		"pro"
	],
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dayPeriods-format-narrow-morning": "prijepodne",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-thu-relative+0": "ovaj četvrtak",
	"dateFormatItem-GyMMMd": "d. MMM y. G",
	"field-day-relative+2": "prekosutra",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormatItem-H": "HH",
	"months-standAlone-abbr": [
		"sij",
		"velj",
		"ožu",
		"tra",
		"svi",
		"lip",
		"srp",
		"kol",
		"ruj",
		"lis",
		"stu",
		"pro"
	],
	"quarters-format-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y. G",
	"dateFormatItem-M": "L.",
	"days-standAlone-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"dayPeriods-format-narrow-evening": "navečer",
	"dateFormatItem-MMMMd": "d. MMMM",
	"dayPeriods-format-abbr-noon": "podne",
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "ova nedjelja",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"1kv",
		"2kv",
		"3kv",
		"4kv"
	],
	"field-sun-relative+1": "sljedeća nedjelja",
	"eraAbbr": [
		"pr. Kr.",
		"p. Kr."
	],
	"field-minute": "Minuta",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"field-day-relative+-1": "jučer",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'u' {0}",
	"field-day-relative+-2": "prekjučer",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateTimeFormat-full": "{1} 'u' {0}",
	"field-fri-relative+0": "ovaj petak",
	"dateFormatItem-yMMMM": "LLLL y.",
	"field-fri-relative+1": "sljedeći petak",
	"field-day": "Dan",
	"days-format-wide": [
		"nedjelja",
		"ponedjeljak",
		"utorak",
		"srijeda",
		"četvrtak",
		"petak",
		"subota"
	],
	"field-zone": "Vremenska zona",
	"months-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4.",
		"5.",
		"6.",
		"7.",
		"8.",
		"9.",
		"10.",
		"11.",
		"12."
	],
	"dateFormatItem-y": "y.",
	"field-year-relative+-1": "prošle godine",
	"dayPeriods-format-narrow-night": "noću",
	"field-month-relative+-1": "prošli mjesec",
	"dateFormatItem-hm": "hh:mm a",
	"days-format-abbr": [
		"ned",
		"pon",
		"uto",
		"sri",
		"čet",
		"pet",
		"sub"
	],
	"eraNames": [
		"Prije Krista",
		"Poslije Krista"
	],
	"dateFormatItem-yMMMd": "d. MMM y.",
	"days-format-narrow": [
		"N",
		"P",
		"U",
		"S",
		"Č",
		"P",
		"S"
	],
	"dayPeriods-format-narrow-earlyMorning": "ujutro",
	"days-standAlone-narrow": [
		"n",
		"p",
		"u",
		"s",
		"č",
		"p",
		"s"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "Mjesec",
	"field-tue-relative+0": "ovaj utorak",
	"field-tue-relative+1": "sljedeći utorak",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-MMMMEd": "E, d. MMMM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"dateFormat-short": "dd.MM.y.",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-format-narrow-afternoon": "popodne",
	"dayPeriods-format-narrow-noon": "P",
	"field-second": "Sekunda",
	"field-sat-relative+-1": "prošla subota",
	"dateFormatItem-yMMMEd": "E, d. MMM y.",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-month-relative+0": "ovaj mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"dateFormatItem-Ed": "E, d.",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "Tjedan",
	"dateFormat-medium": "d. MMM y.",
	"field-year-relative+0": "ove godine",
	"field-week-relative+-1": "prošli tjedan",
	"field-year-relative+1": "sljedeće godine",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "hh:mm:ss a",
	"dateFormatItem-GyMMM": "LLL y. G",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan"
}
//end v1.x content
);
